@@ -421,8 +421,8 @@ def get_model_name_from_bam_header(header):
 def get_model_from_bam_header(header):
     model_jsons = get_models_from_bam_header(header)
 
-    if len(model_jsons) > 0:
-        logger.warn(f"Loading model {model_jsons[0]['name']}, but more than one detected ({', '.join([m['name'] for m in model_jsons])}).")
+    if len(model_jsons) > 1:
+        logger.warning(f"Loading model {model_jsons[0]['name']}, but more than one detected ({', '.join([m['name'] for m in model_jsons])}).")
 
     return model_jsons[0]
 
@@ -448,4 +448,4 @@ def bam_header_has_model(header):
 
 
 def generate_read_name(movie_name, zmw, split_read_index):
-    return f'{movie_name}/1{zmw:09d}{split_read_index:03d}/ccs'
\ No newline at end of file
+    return f'{movie_name}/1{zmw:09d}{split_read_index:03d}/ccs'
